# PBS Exporter

Prometheus Exporter for Proxmox Backup Server.

## Installation

```bash
pip install pbs_exporter


export PBS_BASE_URL="https://your-proxmox-backup-server"
export PBS_TOKEN="your_token"
pbs_exporter



token:

root@pam!root_test
f5db1784-f82c-4f1a-8061-5217caa05e24

curl -k -H "Authorization: Bearer root@pam\!root_test:f5db1784-f82c-4f1a-8061-5217caa05e24" https://10.10.10.141:8007/api2/json/admin/datastore


bachtn3@pbs!test:d5ebb950-a8db-453c-a8d0-1976ace1b8a2